==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/release-notes/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Overview",
                    "href":"overview.html"
                },
                {
                    "title":"New Features in Release 24.4",
                    "href":"new-features-release-24.4.html"
                },
                {
                    "title":"New Features in Release 24.3",
                    "href":"new-features-release-24.3.html"
                },
                {
                    "title":"New Features in Release 24.1",
                    "href":"new-features-release-24.1.html"
                },
                {
                    "title":"New Features in Release 23.3",
                    "href":"new-features-release-23.3.html"
                },
                {
                    "title":"New Features in Release 23.1",
                    "href":"new-features-release-23.1.html"
                },
                {
                    "title":"New Features in Release 22.3",
                    "href":"new-features-release-22.3.html"
                },
                {
                    "title":"New Features in Release 22.2",
                    "href":"new-features-release-22.2.html"
                },
                {
                    "title":"New Features in Release 22.1",
                    "href":"new-features-release-22.1.html"
                },
                {
                    "title":"New Features in Release 21.2",
                    "href":"new-features-release-21.2.html"
                },
                {
                    "title":"New Features in Release 21.1",
                    "href":"new-features-release-21.1.html"
                },
                {
                    "title":"New Features in Release 20.3",
                    "href":"new-features-release-20.3.html"
                },
                {
                    "title":"New Features in Release 20.2",
                    "href":"new-features-release-20.2.html"
                },
                {
                    "title":"New Features in Release 20.1",
                    "href":"new-features-release-20.1.html"
                },
                {
                    "title":"New Features in Release 19.5",
                    "href":"new-features-release-19.5.html"
                },
                {
                    "title":"New Features in Release 19.3",
                    "href":"new-features-release-19.3.html"
                },
                {
                    "title":"New Features in Release 19.1",
                    "href":"new-features-release-19.1.html"
                },
                {
                    "title":"New Features in Release 18.3",
                    "href":"new-features-release-18.3.html"
                },
                {
                    "title":"New Features in Release 18.1",
                    "href":"new-features-release-18.1.html"
                },
                {
                    "title":"Distributions",
                    "href":"distributions.html"
                },
                {
                    "title":"Building from Source Code in the Community Edition",
                    "href":"building-source-code-community-edition.html"
                },
                {
                    "title":"Known Issues",
                    "href":"known-issues.html#GUID-EB6234FD-9589-4DD2-B477-B4F1FC270C77"
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/release-notes/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Overview",
                    "href":"overview.html"
                },
                {
                    "title":"New Features in Release 25.3",
                    "href":"new-features-release-25.3.html"
                },
                {
                    "title":"New Features in Release 25.1",
                    "href":"new-features-release-25.1.html"
                },
                {
                    "title":"New Features in Release 24.4",
                    "href":"new-features-release-24.4.html"
                },
                {
                    "title":"New Features in Release 24.3",
                    "href":"new-features-release-24.3.html"
                },
                {
                    "title":"New Features in Release 24.1",
                    "href":"new-features-release-24.1.html"
                },
                {
                    "title":"New Features in Release 23.3",
                    "href":"new-features-release-23.3.html"
                },
                {
                    "title":"New Features in Release 23.1",
                    "href":"new-features-release-23.1.html"
                },
                {
                    "title":"New Features in Release 22.3",
                    "href":"new-features-release-22.3.html"
                },
                {
                    "title":"New Features in Release 22.2",
                    "href":"new-features-release-22.2.html"
                },
                {
                    "title":"New Features in Release 22.1",
                    "href":"new-features-release-22.1.html"
                },
                {
                    "title":"New Features in Release 21.2",
                    "href":"new-features-release-21.2.html"
                },
                {
                    "title":"New Features in Release 21.1",
                    "href":"new-features-release-21.1.html"
                },
                {
                    "title":"New Features in Release 20.3",
                    "href":"new-features-release-20.3.html"
                },
                {
                    "title":"New Features in Release 20.2",
                    "href":"new-features-release-20.2.html"
                },
                {
                    "title":"New Features in Release 20.1",
                    "href":"new-features-release-20.1.html"
                },
                {
                    "title":"New Features in Release 19.5",
                    "href":"new-features-release-19.5.html"
                },
                {
                    "title":"New Features in Release 19.3",
                    "href":"new-features-release-19.3.html"
                },
                {
                    "title":"New Features in Release 19.1",
                    "href":"new-features-release-19.1.html"
                },
                {
                    "title":"New Features in Release 18.3",
                    "href":"new-features-release-18.3.html"
                },
                {
                    "title":"New Features in Release 18.1",
                    "href":"new-features-release-18.1.html"
                },
                {
                    "title":"Distributions",
                    "href":"distributions.html"
                },
                {
                    "title":"Known Issues",
                    "href":"known-issues.html#GUID-EB6234FD-9589-4DD2-B477-B4F1FC270C77"
                }
            ]
        }
    ]
});
